Trim dates outside of the defined timeframe
date_trim_outliers(new_dates, dmin, dmax, cols, original_dates)A <list> of 2 elements: the update input vector where date
values that are out of the specified timeframe are replaced by NA,
and a vector of the out of timeframe values.
A <vector> of the new date values
A <Date> value with the minimum date
A <Date> value with the maximum date
A <character> with the name of the date column of interest
A <vector> of the original date values