Detect misspelled options in columns to be cleaned
detect_misspelled_options(data, dictionary)A <list> with the indexes of the misspelled values in every
column that needs to be cleaned.
The input <data.frame> or <linelist>
A <data.frame> with the dictionary associated with
the input data. This is expected to be compatible with the
matchmaker package and must contain the following four columns:
optionsThis column contains the current values used to represent the different groups in the input data frame (required).
valuesThe values that will be used to replace the current options (required).
grpThe name of the columns where every option belongs to (required).
ordersThis defines the user-defined order of different options (optional).