This function is called at each iteration of the constant data removal process until no constant data remains.
perform_remove_constants(data, cutoff)A <list> with the input dataset where all empty rows and
columns as well as constant columns have been removed.
The input <data.frame> or <linelist>
A <numeric> value specifying the cut-off for removing
empty rows and columns. If provided, only rows and columns with a
percentage of missing data greater than this cut-off will be removed.
The default is 1.