Unnest an element of the data cleaning report
unnest_report(report, what, ...)The input object where the specified element has been unnested and removed.
An object of type <list>
A <character> with the name of the specific data cleaning
report which would be displayed. The possible values are:
incorrect_date_sequenceTo display rows with the incorrect date sequences
colnamesTo display the column names before and after cleaning
converted_into_numericTo display the names of the columns that that have been converted into numeric
date_standardizationTo display rows in the cleaned data with date values that are outside of the specified time frame, and rows with date values that comply with multiple formats
misspelled_valuesTo display the detected misspelled values
removed_duplicatesTo display the duplicated rows that have been removed
found_duplicatesTo display the duplicated rows
constant_dataTo display the constant data i.e. constant columns, empty rows and columns
missing_values_replaced_atTo display the names of the columns where the missing value strings have been replaced with NA
incorrect_subject_idTo display the missing, duplicated and invalid subject subject IDs
scanning_resultTo display the output of the scan_data() function
Any other extra argument